@@ -1,6 +1,6 @@
 #coding:utf-8
 
-from .util import send_mail_util, json_util
+from .util import send_mail_util, json_util, Url_Sp, http_request
 
 class Tool(object):
     def __init__(self):
@@ -14,10 +14,13 @@ class Tool(object):
     def json_change(self, data):
         return json_util(data)
 
+    def url_sp(self, url, data):
+        return Url_Sp(url, data)
+        
+    def http_request(self, type, url, **kwargs):
+        return http_request(type, url, **kwargs)
 
-tool = Tool()
-a = tool.json_change(1)
-print(type(a))
+
 
 
 
